@@ -3,11 +3,15 @@
 from openshift.dynamic.exceptions import ResourceNotFoundError
 
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine import VirtualMachine
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class VirtualMachineRestore(NamespacedResource):
     """
     VirtualMachineRestore object.
@@ -64,7 +68,7 @@ class VirtualMachineRestore(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        self.logger.info(
+        LOGGER.info(
             f"Wait for {self.kind} {self.name} status to be complete = {status}"
         )
 
